package tests;

import utest.*;
import http.Request;
import http.Response;
import http.Server;
import http.Status;

public class GetTest extends Testable {
    public void assertion() {
        Server s = new Server("www", "example.com");
        Request rq;
        Response rp;

        rq = Request.fromString(s, "GET /css/style.css HTTP/1.1");
        rp = rq.response();
        check("The status is not \"Not found\" for a missing file.",
          rp.status == Status.NOT_FOUND);
        rq = Request.fromString(s, "GET /index.html HTTP/1.1");
        rp = rq.response();
        check("The status is \"OK\" for an existing file with a missing \"host\" field.",
          rp.status == Status.NOT_FOUND);
        rq.addHeader("Host", "foo.com");
        rp = rq.response();
        check("The status is not \"Not Found\" for a different host name.",
          rp.status == Status.NOT_FOUND);
        rq.addHeader("Host", "example.com");
        rp = rq.response();
        check("The status is not \"OK\" for a proper host name and an existing file.",
          rp.status == Status.OK &&
          rp.getHeader("Connection").equals("close") &&
          rp.getHeader("Content-length").equals("128") &&
          rp.getHeader("Content-type").equals("text/html"));
    }

    public int score() { return 5; }
    public String description() { return "http.method.Get"; }

    public String className() { return "http.method.Get"; }
    public Object[] expectedMethods() throws Exception {
        return new Object[]
        { method(className() + ".execute", Request.class)
        , method(className() + ".response")
        , constructor(className())
        };
    }

    public static void main(String... args) {
        Test.main(new GetTest());
    }
}
