package tests;

import utest.*;
import http.Request;
import http.Response;
import http.Server;
import http.Status;

public class RequestTest extends Testable {
    public void assertion() {
        Request r1 = Request.fromString(null, "PUT /index.html HTTP/1.1");
        Request r2 = Request.fromString(null, "TAIL /css/style.css HTTP/1.1");
        Request r3 = Request.fromString(null, "GET /lulz.html");
        Request r4 = Request.fromString(null, "HEAD");
        Request r5 = Request.fromString(null, "GET HTTP/1.1");
        Request r6 = Request.fromString(null, "");
        Request r7 = Request.fromString(null, "dhfsdhfdo éJK N+4lj 34lvsdmk vc");

        check("The fromString() does not parse properly formatted input.",
          r1 != null && r2 != null);
        check("The URI field is not set correctly.",
          r1.uri.equals("/index.html") && r2.uri.equals("/css/style.css"));
        check("The fromString() method parses invalid input.",
          r3 == null && r4 == null && r5 == null && r6 == null && r7 == null);
        check("PUT and TAIL methods should not be supported.",
          r1.response().status == Status.NOT_IMPLEMENTED &&
          r2.response().status == Status.NOT_IMPLEMENTED);
    }

    public int score() { return 4; }
    public String description() { return "http.Request"; }

    public String className() { return "http.Request"; }
    public Object[] expectedMethods() throws Exception {
        return new Object[]
        { staticMethod(className() + ".fromString", Server.class, String.class)
        , method(className() + ".response")
        , method("http.Message.addHeader", String.class, String.class)
        , method("http.Message.getHeader", String.class)
        };
    }

    public Object[] expectedFields() throws Exception {
        return new Object[]
        { field(className() + ".uri")
        , field(className() + ".server")
        };
    }



    public static void main(String... args) {
        Test.main(new RequestTest());
    }
}
