package tests;

import utest.*;
import http.Response;
import http.Status;

public class ResponseTest extends Testable {
    public void assertion() {
        Response r1, r2;

        r1 = new Response(Status.OK);
        r2 = new Response(Status.BAD_REQUEST, "This is a body.");
        check("The status code is not set correctly.",
          r1.status == Status.OK && r2.status == Status.BAD_REQUEST);
        check("The body is not set correctly.",
          r1.body == null && r2.body.equals("This is a body."));
        check("The toString() method does not work correctly.",
          r1.toString().equals("HTTP/1.1 200 OK\n\n") &&
          r2.toString().equals("HTTP/1.1 400 Bad Request\n\nThis is a body."));
        r1.addHeader("Connection", "close");
        r2.addHeader("Content-Type", "text/html");
        check("The toString() method does not work properly in presence of headers.",
          r1.toString().equals("HTTP/1.1 200 OK\nCONNECTION: close\n\n") &&
          r2.toString().equals("HTTP/1.1 400 Bad Request\nCONTENT-TYPE: text/html\n\nThis is a body."));
    }

    public int score() { return 3; }
    public String description() { return "http.Response"; }

    public String className() { return "http.Response"; }
    public Object[] expectedMethods() throws Exception {
        return new Object[]
        { constructor(className(), Status.class, String.class)
        , constructor(className(), Status.class)
        , method(className() + ".toString")
        , method("http.Message.addHeader", String.class, String.class)
        , method("http.Message.getHeader", String.class)
        };
    }

    public Object[] expectedFields() throws Exception {
        return new Object[]
        { field(className() + ".status")
        , field(className() + ".body")
        };
    }

    public static void main(String... args) {
        Test.main(new ResponseTest());
    }
}
