package tests;

import utest.*;
import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.InputStream;
import java.io.PrintStream;
import http.Server;

public class ServerTest2 extends Testable {
    public void assertion() {
        InputStream in = System.in;
        PrintStream out = System.out;
        ByteArrayOutputStream baos = new ByteArrayOutputStream();
        Server srv = new Server("www", "localhost:8000");
        String rq, rp, s;

        rq  = "GET /sub.html HTTP/1.1\n";
        rq += "Host: localhost:8000\n\n";
        System.setIn(new ByteArrayInputStream(rq.getBytes()));
        System.setOut(new PrintStream(baos));
        try {
            srv.serve();
        }
        finally {
            System.setIn(in);
            System.setOut(out);
        }
        rp  = "\n";
        rp += "<html>\n";
        rp += "<title>Yet Another WWW Test Page</title>\n";
        rp += "<body>\n";
        rp += "<p>This works still!</p>\n";
        rp += "</body>\n";
        rp += "</html>\n";
        s = baos.toString();
        check("The serve() method did not return the proper answer for getting an existing page.",
          s.startsWith("HTTP/1.1 200 OK\n") &&
          s.contains("CONNECTION: close\n") &&
          s.contains("CONTENT-LENGTH: 96\n") &&
          s.contains("CONTENT-TYPE: text/html") &&
          s.endsWith(rp));

        baos = new ByteArrayOutputStream();
        rq  = "GET /sub.html HTTP/1.1\n";
        rq += "\n";
        System.setIn(new ByteArrayInputStream(rq.getBytes()));
        System.setOut(new PrintStream(baos));
        try {
            srv.serve();
        }
        finally {
            System.setIn(in);
            System.setOut(out);
        }
        s = baos.toString();
        check("The serve() method did not return the proper answer for a missing host name.",
          s.startsWith("HTTP/1.1 404 Not Found\n") &&
          s.contains("CONNECTION: close\n") &&
          s.contains("CONTENT-LENGTH: 33\n") &&
          s.contains("CONTENT-TYPE: text/plain\n") &&
          s.endsWith("\nThe requested page was not found."));

        baos = new ByteArrayOutputStream();
        rq  = "PUT /sub.html HTTP/1.1\n";
        rq += "\n";
        System.setIn(new ByteArrayInputStream(rq.getBytes()));
        System.setOut(new PrintStream(baos));
        try {
            srv.serve();
        }
        finally {
            System.setIn(in);
            System.setOut(out);
        }
        s = baos.toString();
        check("The serve() method did not return the proper answer for an unknown method.",
          s.equals("HTTP/1.1 501 Not Implemented\n\n"));

        baos = new ByteArrayOutputStream();
        rq  = ":-)\n";
        System.setIn(new ByteArrayInputStream(rq.getBytes()));
        System.setOut(new PrintStream(baos));
        try {
            srv.serve();
        }
        finally {
            System.setIn(in);
            System.setOut(out);
        }
        s = baos.toString();
        check("The serve() method did not return the proper answer for an invalid request.",
          s.equals("HTTP/1.1 400 Bad Request\n\n"));
    }

    public int score() { return 4; }
    public String description() { return "http.Server (part 2)"; }

    public String className() { return "http.Server"; }
    public Object[] expectedMethods() throws Exception {
        return new Object[]
        { constructor(className(), String.class, String.class)
        , staticMethod(className() + ".resolveMethod", String.class)
        , method(className() + ".serve")
        };
    }

    public Object[] expectedFields() throws Exception {
        return new Object[]
        { field(className() + ".root")
        , field(className() + ".host")
        };
    }

    public static void main(String... args) {
        Test.main(new ServerTest2());
    }
}
